#
# A sample to illustrate a PerlMx::Samples::Simple filter in action.
#
# Compare SampleFilter.pm.
#

package PerlMx::Samples::SimpleSampleFilter;

use 5.006;
use strict;
use warnings;

use PerlMx::Simple;
use base qw(PerlMx::Simple);

use Sys::Hostname;
use Fcntl;

# utility functions

sub make_temp_file {
    my $seq = int rand(10000000);
    my $file = "/tmp/smfi$seq";
    my $fh;
    my $iter = 0;
    my $flags = O_CREAT|O_EXCL|O_RDWR|O_BINARY;
    # XXX Real code should use File::Temp::mkstemp() but that's not
    # available in Perl v5.6.0.
    while (!sysopen($fh, $file, $flags, 0600)) {
	$seq = int rand(10000000);
	$file = "/tmp/smfi$seq";
	return if ++$iter > 10;
    }
    return ($file,$fh);
}

sub cleanup {
    my $ctx = shift;
    my $ok = shift;
    my $status = CONTINUE;
    if (exists $ctx->{fh} and !close($ctx->{fh})) {
	unlink($ctx->{fname});
	$status = TEMPFAIL;
    }
    elsif ($ok) {
	# add a header to the message announcing our presence
	warn "addhedr [$ctx] [interp#$ctx->{__perlmx_id}]\n";
	$ctx->addheader("X-Archived", $ctx->{fname} . '@' . hostname());
    }
    else {
	unlink($ctx->{fname});
    }
    return $status;
}

# callbacks

sub pmx_connect {
    my $ctx = shift;
    my $name = shift;
    warn "connect [$ctx] [interp#$ctx->{__perlmx_id}] [$name]\n";
    return CONTINUE;
}

sub pmx_envfrom {
    my $ctx = shift;
    warn "envfrom [$ctx] [interp#$ctx->{__perlmx_id}]\n";
    @{$ctx}{'fname','fh'} = make_temp_file() or return TEMPFAIL;
    return CONTINUE;
}

sub pmx_headers {
    my $ctx = shift;
    my $h = shift;
    print { $ctx->{fh} } $h;
    print { $ctx->{fh} } "\r\n";	# blank line
    return CONTINUE;
}

sub pmx_body {
    my $ctx = shift;
    my $body = shift;
    print { $ctx->{fh} } $body;
    return $ctx->cleanup(1);
}

sub pmx_abort {
    my $ctx = shift;
    return $ctx->cleanup(0);
}

sub pmx_close {
    return ACCEPT;
}

warn "Loading " . __PACKAGE__ . "\n";

1;

__END__

=head1 NAME

PerlMx::Samples::SimpleSampleFilter - Logs messages

=head1 SYNOPSIS

    pmx1 PerlMx::Samples::SimpleSampleFilter >& SimpleSampleFilter.log &

=head1 DESCRIPTION

This is a sample PerlMx::Simple filter that logs messages in the /tmp
directory.  Each message logged has an additional X-Archived header that
specifies the file name to which it has been logged.

=head1 COPYRIGHT

Copyright (c) 2000-2003 ActiveState. All rights reserved.

=head1 SEE ALSO

L<PerlMx>, L<PerlMx::Simple>, L<perl>

=cut
