#
# A sample PerlMx filter that blocks messages like the ILOVEYOU worm.
#

package PerlMx::Samples::WormFilter;

use PerlMx;
use base qw(PerlMx);

my $DEBUG = 1;

# callbacks

my $from;

sub cb_connect {
    my $ctx = shift;
    my $name = shift;
    $from = $name;
    return SMFIS_CONTINUE;
}

sub cb_header {
    my $ctx = shift;
    my $headerf = shift;
    my $headerv = shift;
    if ($headerf =~ /^Subject$/i and $headerv =~ /\bILU\b/) {
        warn "ILU worm received from $from discarded\n" if $DEBUG;
	return SMFIS_DISCARD;		# silently drop
    }
    return SMFIS_CONTINUE;
}

sub new {
    return bless {
    	CONNECT	=> \&cb_connect,
	HEADER	=> \&cb_header,
    }, shift;
}

warn "Loading " . __PACKAGE__ . "\n" if $DEBUG;

1;

__END__

=head1 NAME

PerlMx::Samples::WormFilter -- Scans subject lines for possible viruses 

=head1 SYNOPSIS

    pmx1 PerlMx::Samples::WormFilter >& WormFilter.log

=head1 DESCRIPTION

A sample filter that scans message headers for a subject line that might
indicate the presence of a virus. If the the scan string is encountered,
the message is silently dropped.

=head1 COPYRIGHT

Copyright (c) 2000-2003 ActiveState. All rights reserved.

=head1 SEE ALSO

L<PerlMx>, L<perl>

=cut
