package PerlMx::Log;

use strict;
use base qw(PureMessage::Logger Exporter);
our @EXPORT_OK = qw(LOG_DEBUG LOG_INFO LOG_NOTICE LOG_WARNING
		    LOG_ERR LOG_CRIT LOG_ALERT LOG_EMERG);

use PureMessage::Logger qw(LOG_DEBUG LOG_INFO LOG_NOTICE LOG_WARNING
		           LOG_ERR LOG_CRIT LOG_ALERT LOG_EMERG);

use PerlMx ();
push(@PerlMx::ISA, __PACKAGE__);

require PureMessage::_sys;
use PureMessage::Config qw(%config);

sub _log_prefix {
    my $self = shift;
    return "" unless ref($self);
    $self->m_mail_queue_id;
}

sub _log_ident {
    "milter";
}

1;

__END__

=head1 NAME

PerlMx::Log - PureMessage logger

=head1 SYNOPSIS

 use base 'PerlMx';
 use PerlMx::Log qw(LOG_INFO);

 sub xxx_cb {
     my $ctx = shift;
     $ctx->log(LOG_INFO, "The XXX callback was invoked");
 }

=head1 DESCRIPTION

This module inserts the log() method into the PerlMx class and also
exports various log priority constants.  The log() method can be
invoked to write log messages to the PureMessage log file.  The method
takes two arguments, a priority level and a message.  It can be called
as both a class and an instance method.  Calling it as an instance
method is prefered as that allows the log entries to be prefixed with
the relevant queue-id of the current message.

The pritority argument should be one of the following constants
(exported on request by this module):

    LOG_DEBUG
    LOG_INFO
    LOG_NOTICE
    LOG_WARNING
    LOG_ERR
    LOG_CRIT
    LOG_ALERT
    LOG_EMERG

A text string ("DEBUG" or "ERR") is also accepted but is slightly less
efficient.

=head1 FILES

The F<log/pmx_log> is the default log file written to by the log() method
described above.  The C<log_to> entry in the F<pmx.conf> can be used
to redirect log output to a different file.

The log file contains a sequence of log entries, one per line.  The
format typically looks like this:

  2 2002-02-12T05:06:10Z [16838:3075] g1C569gA016837: accepted

The first field is a number that indicate the log priority level.  The
levels are the same as those found for syslog:

    0 debug
    1 info
    2 notice
    3 warning
    4 error

The next field is a timestamp in ISO 8601 format.  A trailing "Z"
means UTC time.

The next field contains the process/thread id of the milter.  If
debug mode is on, then it might also contain a module line and a line
number indicating where the log entry was triggered from.

The rest is of a log entry is free text.  For log messages generated
during the processing of a specific message, then the free text part
will be prefixed by a message queue id as shown in this example.

=head1 SEE ALSO

L<PerlMx>, L<pmx.conf>

=cut
